import {
    SELFSHOP, PURCHASE_DATA, PURCHASE_RETURN_REFRESH,
    SALE_RETURN_REFRESH, MY_REFRESH, INDEX_REFRESH,
    getLocalStorage, setLocalStorage
} from '@assets/js/self.js'
import { formatTel } from '@assets/js/format.js'
/**
 * 获取用户信息、机构详情
 * @param {*} _this this指向
 * @param {*} cb 回调
 */
export function getInfoRes (_this, cb) {
    const curParams = {
        shop_id: getLocalStorage(SELFSHOP) ? getLocalStorage(SELFSHOP).id : ''
    }
    _this.$http.get(_this.$myApi.SUPPLIWRDETAIL, curParams)
        .then(data => {
            _this.supplier = data
            if (data && data.phone) {
                _this.supplier_tel = formatTel(data.phone)
            }
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

/**
 * 获取机构列表及选中的机构
 * @param {*} _this this指向
 * @param {*} cb 回调
 */
export function getSupplierRes (_this, cb) {
    _this.$http.get(_this.$myApi.SUPPLIER)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

/**
 * 切换机构
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} cb 回调
 */
export function changeSupplierRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.CHANGE_SUPPLIER, curParams)
        .then(data => {
            setLocalStorage(MY_REFRESH, true)
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.$toast('切换机构失败')
            _this.showPicker = false
        })
}

/**
 * 供应商列表
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} cb 回调
 */
export function providerRes (_this, curParams, cb) {
    const params = curParams || { type: 1 }
    _this.$http.get(_this.$myApi.PROVIDERLIST, params)
        .then(data => {
            if (data && !curParams) {
                _this.supplier = data
                _this.cursupplier = data[0]
            }
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 商铺列表
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} cb 回调
 */
export function shopListRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.SHOPLIST, curParams)
        .then(data => {
            _this.list = _this.page === 1 ? data.list : _this.list.concat(data.list)
            _this.page = data.page
            _this.more = data.more
            _this.locked = false
            _this.isloading = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.locked = false
            _this.isloading = false
        })
}

/**
 * 修改购物车数量
 * @param {*} _this this指向
 * @param {*} type 类型（1：采购计划；2：采购退货；3：销售退货） （curParams参数）
 * @param {*} good_id 商品id （curParams参数）
 * @param {*} num 商品数量 （curParams参数）
 * @param {*} provider_id 供货商id（采购退货必需） （curParams参数）
 * @param {*} shop_id 商铺id（销售退货必需） （curParams参数）
 */
export function cartChangeRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.CHANGECART, curParams)
        .then(data => {
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.$toast('操作失败')
            _this.isClick = false
        })
}

/**
 * 购物车列表
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} type 类型（1:采购计划购物车；2：采购退货购物车；3：销售退货购物车） （curParams参数）
 * @param {*} provider_id 供货商id（采购退货必需） （curParams参数）
 * @param {*} shop_id 商铺id（销售退货必需） （curParams参数）
 * @param {*} cb 回调
 */
export function cartListRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.CARTLIST, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

/**
 * 清空购物车
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} type 类型（1:采购计划购物车；2：采购退货购物车；3：销售退货购物车） （curParams参数）
 * @param {*} provider_id 供货商id（采购退货必需） （curParams参数）
 * @param {*} shop_id 商铺id（销售退货必需） （curParams参数）
 * @param {*} cb 回调
 */
export function cartEmptyRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.CLEARCART, curParams)
        .then(data => {
            _this.$toast('购物车已清空')
            typeof cb === 'function' && cb()
        })
        .catch(() => {})
}

// //////////////////////// 采购管理 //////////////////////

/**
 * 采购计划商品列表、搜索
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} type 类型（1:采购计划购物车；2：采购退货购物车；3：销售退货购物车） （curParams参数）
 * @param {*} provider_id 供货商id（采购退货必需） （curParams参数）
 * @param {*} shop_id 商铺id（销售退货必需） （curParams参数）
 * @param {*} cb 回调
 */
export function GoodsListRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.CATEGOODS, curParams)
        .then(data => {
            _this.list = _this.page === 1 ? data.list : _this.list.concat(data.list)
            _this.page = data.page
            _this.more = data.more
            _this.locked = false
            _this.isloading = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.locked = false
            _this.isloading = false
        })
}

/**
 * 提交采购计划
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} supplier_shop_id 仓库id 必填 （curParams参数）
 * @param {*} warn_id 采购预警id （curParams参数）
 * @param {*} remark 备注 （curParams参数）
 * @param {*} cb 回调
 */
export function addPlanRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.ADDPLAN, curParams)
        .then(data => {
            _this.$toast('提交成功')
            setLocalStorage(PURCHASE_DATA, true)
            setLocalStorage(INDEX_REFRESH, true)
            setTimeout(() => {
                _this.$router.go(-2)
                _this.isloading = false
            }, 1000)
            typeof cb === 'function' && cb()
        })
        .catch(() => {
            _this.isloading = false
        })
}

/**
 * 采购管理订单详情 1：采购计划，2：采购订单，3：入库订单
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购计划、采购订单、入库订单id （curParams参数）
 * @param {*} type 订单类型（1：采购计划，2：采购订单，3：入库订单） （curParams参数）
 * @param {*} cb 回调
 */
export function purDetailRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.PURCHASE_DETAIL, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

/**
 * 验收入库
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} cb 回调
 */
export function purCheckDetailRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.ENTRYCHECK, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

/**
 * 采购计划--立即审核
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购计划id （curParams参数）
 * @param {*} cb 回调
 */
export function purAuditRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.PLANAUDIT, curParams)
        .then(data => {
            _this.$toast('审核通过，已生成采购订单')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 采购计划--删除
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购计划id （curParams参数）
 * @param {*} cb 回调
 */
export function purDeleteRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.PLANDELETE, curParams)
        .then(data => {
            _this.$toast('已删除')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 采购--相关单据
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购计划id （curParams参数）
 * @param {*} cb 回调
 */
export function purBillRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.PLANBILLS, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

/**
 * 采购订单-取消订单
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购计划id （curParams参数）
 * @param {*} cb 回调
 */
export function purOrderCancelRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.PURORDERCANCEL, curParams)
        .then(data => {
            _this.$toast('已取消')
            _this.isClick = false
            typeof cb === 'function' && cb()
        })
        .catch(() => {
            _this.isClick = false
        })
}

// //////////////////////// 销售管理 //////////////////////
/**
 * 销售订单详情、销售出库订单详情
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 订单id （curParams 参数）
 * @param {*} cb 回调
 */
export function saleDetailRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.SALEDETAIL, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}
/**
 * 销售订单-编辑详情
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 订单id （curParams 参数）
 * @param {*} cb 回调
 */
export function saleEditDetailRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.SALE_EDIT_DETAIL, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

// //////////////////////// 采购退货 //////////////////////
/**
 * 提交采购退货
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} supplier_shop_id 仓库id 必填 （curParams参数）
 * @param {*} provider_id 供应商id（curParams参数）
 * @param {*} remark 备注 （curParams参数）
 * @param {*} cb 回调
 */
export function addPurReturnRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.PURCHASERETURN_CREATE, curParams)
        .then(data => {
            _this.$toast('提交成功')
            setLocalStorage(PURCHASE_DATA, true)
            setLocalStorage(PURCHASE_RETURN_REFRESH, true)
            setTimeout(() => {
                _this.$router.go(-2)
                _this.isloading = false
            }, 1000)
            typeof cb === 'function' && cb()
        })
        .catch(() => {
            _this.isloading = false
        })
}

/**
 * 采购退货--删除
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购退货id （curParams参数）
 * @param {*} cb 回调
 */
export function purReturnDeleteRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.PURCHASERETURN_DETELE, curParams)
        .then(data => {
            _this.$toast('已删除')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 采购退货--审核
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购退货id （curParams参数）
 * @param {*} cb 回调
 */
export function purReturnCheckRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.PURCHASERETURN_CHECK, curParams)
        .then(data => {
            _this.$toast('审核通过')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 采购退货-详情
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购退货id （curParams参数）
 * @param {*} cb 回调
 */
export function purReturnDetailRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.PURCHASERETURN_DETAIL, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

// ////////////////////// 销售退货 ////////////////////////
/**
 * 销售退货 - 提交
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} supplier_shop_id 仓库id 必填 （curParams参数）
 * @param {*} provider_id 供应商id（curParams参数）
 * @param {*} remark 备注 （curParams参数）
 * @param {*} cb 回调
 */
export function addSaleReturnRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.SALERETURN_CREATE, curParams)
        .then(data => {
            _this.$toast('提交成功')
            setLocalStorage(PURCHASE_DATA, true)
            setLocalStorage(SALE_RETURN_REFRESH, true)
            setTimeout(() => {
                _this.$router.go(-3)
                _this.isloading = false
            }, 1000)
            typeof cb === 'function' && cb()
        })
        .catch(() => {
            _this.isloading = false
        })
}

/**
 * 销售退货--删除
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 销售退货id （curParams参数）
 * @param {*} cb 回调
 */
export function saleReturnDeleteRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.SALERETURN_DELETE, curParams)
        .then(data => {
            _this.$toast('已删除')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 销售退货--审核
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 销售退货id （curParams参数）
 * @param {*} cb 回调
 */
export function saleReturnCheckRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.SALERETURN_CHECK, curParams)
        .then(data => {
            _this.$toast('审核通过')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 销售退货-详情
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 销售退货id （curParams参数）
 * @param {*} cb 回调
 */
export function saleReturnDetailRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.SALERETURN_DETAIL, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

// ///////////////////// 商品档案 /////////////////////

/**
 * 商品档案列表、商品档案搜索
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} supplier_shop_id 仓库id （curParams参数）
 * @param {*} cb 回调
 */
export function GoodsRecordRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.GOODSCLASS, curParams)
        .then(data => {
            _this.list = _this.page === 1 ? data.list : _this.list.concat(data.list)
            _this.page = data.page
            _this.more = data.more
            _this.locked = false
            _this.isloading = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.locked = false
            _this.isloading = false
        })
}

// ///////////////////// 赠送入库 /////////////////////
/**
 * 赠送入库--删除
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购退货id （curParams参数）
 * @param {*} cb 回调
 */
export function freeDeleteRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.FREE_DELETE, curParams)
        .then(data => {
            _this.$toast('已删除')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 赠送入库--审核
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 采购退货id （curParams参数）
 * @param {*} cb 回调
 */
export function freeCheckRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.FREE_CHECK, curParams)
        .then(data => {
            _this.$toast('审核通过')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

// ///////////////////// 协助入库 /////////////////////
/**
 * 协助订单--删除
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 协助订单id （curParams参数）
 * @param {*} cb 回调
 */
export function assistDeleteRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.ASSIST_DETELE, curParams)
        .then(data => {
            _this.$toast('已删除')
            _this.isClick = false
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {
            _this.isClick = false
        })
}

/**
 * 协助订单订单详情
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 订单id （curParams参数）
 * @param {*} cb 回调
 */
export function assistDetailRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.ASSIST_DETAIL, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}

/**
 * 协助订单--提交
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} cb 回调
 */
export function assistAddRes (_this, curParams, cb) {
    _this.$http.post(_this.$myApi.ASSIST_CREATE, curParams)
        .then(data => {
            _this.$toast('提交成功')
            setLocalStorage(PURCHASE_DATA, true)
            setLocalStorage(INDEX_REFRESH, true)
            setTimeout(() => {
                _this.$router.go(-2)
                _this.isloading = false
            }, 1000)
            typeof cb === 'function' && cb()
        })
        .catch(() => {
            _this.isloading = false
        })
}

/**
 * 协助订单扫码支付
 * @param {*} _this this指向
 * @param {*} curParams 参数
 * @param {*} id 订单id （curParams参数）
 * @param {*} cb 回调
 */
export function assistCodeRes (_this, curParams, cb) {
    _this.$http.get(_this.$myApi.ASSIST_CODE, curParams)
        .then(data => {
            typeof cb === 'function' && cb(data)
        })
        .catch(() => {})
}
